import { BpmnType } from '../constants';
import { Activity } from './activity';
/**
 * Describes a BPMN ServiceTask.
 * A ServiceTask is used to call either a function from a specific class,
 * or for performing web requests.
 */
export declare class ServiceTask extends Activity {
    readonly bpmnType: BpmnType;
    /**
     * The invocation to be used when the ServiceTask is called.
     */
    invocation: Invocation;
    /**
     * The ServiceTasks type.
     * Currently only supports 'external' and 'internal'.
     */
    type?: ServiceTaskType;
    /**
     * The topic to use in conjunction with external ServiceTasks.
     */
    topic?: string;
    /**
     * The payload to use in conjunction with external ServiceTasks.
     */
    payload?: string;
}
/**
 * Describes all currently supported ServiceTask types.
 */
export declare enum ServiceTaskType {
    external = "external",
    internal = "internal"
}
/**
 * The base class for all invocation types.
 */
export declare abstract class Invocation {
}
/**
 * Used by ServiceTasks.
 * This contains the definition for a method invocation.
 */
export declare class MethodInvocation extends Invocation {
    module: string;
    method: string;
    params: string;
}
