import { BaseElement, FlowNode } from '../base/index';
/**
 * The base class for all events.
 */
export declare abstract class Event extends FlowNode {
}
/**
 * The base class of all event definitions.
 */
export declare abstract class EventDefinition extends BaseElement {
}
/**
 * Contains the definition for an ErrorEvent.
 */
export declare class ErrorEventDefinition extends EventDefinition {
    name?: string;
    code?: string;
    message?: string;
}
/**
 * Contains the definition for a LinkEvent.
 */
export declare class LinkEventDefinition extends EventDefinition {
    readonly name: string;
    constructor(linkName: string);
}
/**
 * Contains the definition for a MessageEvent.
 */
export declare class MessageEventDefinition extends EventDefinition {
    id: string;
    name: string;
}
/**
 * Contains the definition for a SignalEvent.
 */
export declare class SignalEventDefinition extends EventDefinition {
    id: string;
    name: string;
}
/**
 * Contains the definition for a TerminateEndEvent.
 */
export declare class TerminateEventDefinition extends EventDefinition {
}
/**
 * Contains the definition for a TimerEvent.
 */
export declare class TimerEventDefinition extends EventDefinition {
    enabled?: boolean;
    timerType: TimerType;
    value: string;
}
/**
 * Contains all timer types that are currently supported.
 */
export declare enum TimerType {
    timeCycle = 0,
    timeDate = 1,
    timeDuration = 2
}
